BookCtrlEventMethods

Trait BookCtrlEventMethods 

pub trait BookCtrlEventMethods: NotifyEventMethods {
    // Provided methods
    fn get_old_selection(&self) -> c_int { ... }
    fn set_old_selection(&self, page: c_int) { ... }
    fn set_selection(&self, page: c_int) { ... }
}
This trait represents C++ wxBookCtrlEvent class’s methods and inheritance.

See BookCtrlEventIsOwned documentation for the class usage.

Provided Methods

fn get_old_selection(&self) -> c_int

Returns the page that was selected before the change, wxNOT_FOUND if none was selected.

See C++ wxBookCtrlEvent::GetOldSelection()’s documentation.

fn set_old_selection(&self, page: c_int)

Sets the id of the page selected before the change.

See C++ wxBookCtrlEvent::SetOldSelection()’s documentation.

fn set_selection(&self, page: c_int)

Sets the selection member variable.

See C++ wxBookCtrlEvent::SetSelection()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors