CalculateLayoutEventMethods

Trait CalculateLayoutEventMethods 

pub trait CalculateLayoutEventMethods: EventMethods {
    // Provided methods
    fn get_flags(&self) -> c_int { ... }
    fn get_rect(&self) -> Rect { ... }
    fn set_flags(&self, flags: c_int) { ... }
    fn set_rect<R: RectMethods>(&self, rect: &R) { ... }
}
This trait represents C++ wxCalculateLayoutEvent class’s methods and inheritance.

See CalculateLayoutEventIsOwned documentation for the class usage.

Provided Methods

fn get_flags(&self) -> c_int

Returns the flags associated with this event.

See C++ wxCalculateLayoutEvent::GetFlags()’s documentation.

fn get_rect(&self) -> Rect

Before the event handler is entered, returns the remaining parent client area that the window could occupy.

See C++ wxCalculateLayoutEvent::GetRect()’s documentation.

fn set_flags(&self, flags: c_int)

Sets the flags associated with this event.

See C++ wxCalculateLayoutEvent::SetFlags()’s documentation.

fn set_rect<R: RectMethods>(&self, rect: &R)

Call this to specify the new remaining parent client area, after the space occupied by the window has been subtracted.

See C++ wxCalculateLayoutEvent::SetRect()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors