DirDialogMethods

Trait DirDialogMethods 

pub trait DirDialogMethods: DialogMethods {
    // Provided methods
    fn get_message(&self) -> String { ... }
    fn get_path(&self) -> String { ... }
    fn get_paths<A: ArrayStringMethods>(&self, paths: &A) { ... }
    fn set_message(&self, message: &str) { ... }
    fn set_path(&self, path: &str) { ... }
}
This trait represents C++ wxDirDialog class’s methods and inheritance.

See DirDialogIsOwned documentation for the class usage.

Provided Methods

fn get_message(&self) -> String

Returns the message that will be displayed on the dialog.

See C++ wxDirDialog::GetMessage()’s documentation.

fn get_path(&self) -> String

Returns the default or user-selected path.

See C++ wxDirDialog::GetPath()’s documentation.

fn get_paths<A: ArrayStringMethods>(&self, paths: &A)

Fills the array paths with the full paths of the chosen directories.

See C++ wxDirDialog::GetPaths()’s documentation.

fn set_message(&self, message: &str)

Sets the message that will be displayed on the dialog.

See C++ wxDirDialog::SetMessage()’s documentation.

fn set_path(&self, path: &str)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<const OWNED: bool> DirDialogMethods for DirDialogIsOwned<OWNED>