FindDialogEventMethods

Trait FindDialogEventMethods 

pub trait FindDialogEventMethods: CommandEventMethods {
    // Provided methods
    fn get_dialog(&self) -> WeakRef<FindReplaceDialog> { ... }
    fn get_find_string(&self) -> String { ... }
    fn get_flags(&self) -> c_int { ... }
    fn get_replace_string(&self) -> String { ... }
}
This trait represents C++ wxFindDialogEvent class’s methods and inheritance.

See FindDialogEventIsOwned documentation for the class usage.

Provided Methods

fn get_dialog(&self) -> WeakRef<FindReplaceDialog>

Return the pointer to the dialog which generated this event.

See C++ wxFindDialogEvent::GetDialog()’s documentation.

fn get_find_string(&self) -> String

Return the string to find (never empty).

See C++ wxFindDialogEvent::GetFindString()’s documentation.

fn get_flags(&self) -> c_int

Get the currently selected flags: this is the combination of the wxFindReplaceFlags enumeration values.

See C++ wxFindDialogEvent::GetFlags()’s documentation.

fn get_replace_string(&self) -> String

Return the string to replace the search string with (only for replace and replace all events).

See C++ wxFindDialogEvent::GetReplaceString()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors