PreferencesEditorMethods

Trait PreferencesEditorMethods 

pub trait PreferencesEditorMethods: WxRustMethods {
    // Provided methods
    fn add_page<P: PreferencesPageMethods>(&self, page: Option<&P>) { ... }
    fn show<W: WindowMethods>(&self, parent: Option<&W>) { ... }
    fn dismiss(&self) { ... }
    fn should_apply_changes_immediately() -> bool { ... }
    fn shown_modally() -> bool { ... }
}
This trait represents C++ wxPreferencesEditor class’s methods and inheritance.

See PreferencesEditorIsOwned documentation for the class usage.

Provided Methods

fn add_page<P: PreferencesPageMethods>(&self, page: Option<&P>)

Add a new page to the editor.

See C++ wxPreferencesEditor::AddPage()’s documentation.

fn show<W: WindowMethods>(&self, parent: Option<&W>)

Show the preferences dialog or bring it to the top if it’s already shown.

See C++ wxPreferencesEditor::Show()’s documentation.

fn dismiss(&self)

Hide the currently shown dialog, if any.

See C++ wxPreferencesEditor::Dismiss()’s documentation.

fn should_apply_changes_immediately() -> bool

Returns whether changes to values in preferences pages should be applied immediately or only when the user clicks the OK button.

See C++ wxPreferencesEditor::ShouldApplyChangesImmediately()’s documentation.

fn shown_modally() -> bool

Returns whether the preferences dialog is shown modally.

See C++ wxPreferencesEditor::ShownModally()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors