QueryLayoutInfoEventMethods

Trait QueryLayoutInfoEventMethods 

pub trait QueryLayoutInfoEventMethods: EventMethods {
    // Provided methods
    fn get_flags(&self) -> c_int { ... }
    fn get_requested_length(&self) -> c_int { ... }
    fn get_size(&self) -> Size { ... }
    fn set_flags(&self, flags: c_int) { ... }
    fn set_requested_length(&self, length: c_int) { ... }
    fn set_size<S: SizeMethods>(&self, size: &S) { ... }
}
This trait represents C++ wxQueryLayoutInfoEvent class’s methods and inheritance.

See QueryLayoutInfoEventIsOwned documentation for the class usage.

Provided Methods

fn get_flags(&self) -> c_int

Returns the flags associated with this event.

See C++ wxQueryLayoutInfoEvent::GetFlags()’s documentation.

fn get_requested_length(&self) -> c_int

Returns the requested length of the window in the direction of the window orientation.

See C++ wxQueryLayoutInfoEvent::GetRequestedLength()’s documentation.

fn get_size(&self) -> Size

Returns the size that the event handler specified to the event object as being the requested size of the window.

See C++ wxQueryLayoutInfoEvent::GetSize()’s documentation.

fn set_flags(&self, flags: c_int)

Sets the flags associated with this event.

See C++ wxQueryLayoutInfoEvent::SetFlags()’s documentation.

fn set_requested_length(&self, length: c_int)

Sets the requested length of the window in the direction of the window orientation.

See C++ wxQueryLayoutInfoEvent::SetRequestedLength()’s documentation.

fn set_size<S: SizeMethods>(&self, size: &S)

Call this to let the calling code know what the size of the window is.

See C++ wxQueryLayoutInfoEvent::SetSize()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors