RadioBoxMethods

Trait RadioBoxMethods 

pub trait RadioBoxMethods: ControlMethods {
    // Provided methods
    fn create_str<W: WindowMethods, P: PointMethods, S: SizeMethods, A: ArrayStringMethods, V: ValidatorMethods>(
        &self,
        parent: Option<&W>,
        id: c_int,
        label: &str,
        pos: &P,
        size: &S,
        choices: &A,
        major_dimension: c_int,
        style: c_long,
        validator: &V,
        name: &str,
    ) -> bool { ... }
    fn enable_uint(&self, n: c_uint, enable: bool) -> bool { ... }
    fn get_column_count(&self) -> c_uint { ... }
    fn get_item_from_point<P: PointMethods>(&self, pt: &P) -> c_int { ... }
    fn get_item_tool_tip(&self, item: c_uint) -> Option<ToolTipIsOwned<false>> { ... }
    fn get_row_count(&self) -> c_uint { ... }
    fn is_item_enabled(&self, n: c_uint) -> bool { ... }
    fn is_item_shown(&self, n: c_uint) -> bool { ... }
    fn set_item_help_text(&self, item: c_uint, helptext: &str) { ... }
    fn set_item_tool_tip(&self, item: c_uint, text: &str) { ... }
    fn show_uint(&self, item: c_uint, show: bool) -> bool { ... }
}
This trait represents C++ wxRadioBox class’s methods and inheritance.

See RadioBoxIsOwned documentation for the class usage.

Provided Methods

fn create_str<W: WindowMethods, P: PointMethods, S: SizeMethods, A: ArrayStringMethods, V: ValidatorMethods>( &self, parent: Option<&W>, id: c_int, label: &str, pos: &P, size: &S, choices: &A, major_dimension: c_int, style: c_long, validator: &V, name: &str, ) -> bool

Creates the radiobox for two-step construction.

See C++ wxRadioBox::Create()’s documentation.

fn enable_uint(&self, n: c_uint, enable: bool) -> bool

Enables or disables an individual button in the radiobox.

See C++ wxRadioBox::Enable()’s documentation.

fn get_column_count(&self) -> c_uint

Returns the number of columns in the radiobox.

See C++ wxRadioBox::GetColumnCount()’s documentation.

fn get_item_from_point<P: PointMethods>(&self, pt: &P) -> c_int

Returns a radio box item under the point, a zero-based item index, or wxNOT_FOUND if no item is under the point.

See C++ wxRadioBox::GetItemFromPoint()’s documentation.

fn get_item_tool_tip(&self, item: c_uint) -> Option<ToolTipIsOwned<false>>

Returns the tooltip associated with the specified item if any or NULL.

See C++ wxRadioBox::GetItemToolTip()’s documentation.

fn get_row_count(&self) -> c_uint

Returns the number of rows in the radiobox.

See C++ wxRadioBox::GetRowCount()’s documentation.

fn is_item_enabled(&self, n: c_uint) -> bool

Returns true if the item is enabled or false if it was disabled using Enable(n, false).

See C++ wxRadioBox::IsItemEnabled()’s documentation.

fn is_item_shown(&self, n: c_uint) -> bool

Returns true if the item is currently shown or false if it was hidden using Show(n, false).

See C++ wxRadioBox::IsItemShown()’s documentation.

fn set_item_help_text(&self, item: c_uint, helptext: &str)

Sets the helptext for an item.

See C++ wxRadioBox::SetItemHelpText()’s documentation.

fn set_item_tool_tip(&self, item: c_uint, text: &str)

Sets the tooltip text for the specified item in the radio group.

See C++ wxRadioBox::SetItemToolTip()’s documentation.

fn show_uint(&self, item: c_uint, show: bool) -> bool

Shows or hides individual buttons.

See C++ wxRadioBox::Show()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<const OWNED: bool> RadioBoxMethods for RadioBoxIsOwned<OWNED>