SpinCtrlDoubleMethods

Trait SpinCtrlDoubleMethods 

pub trait SpinCtrlDoubleMethods: ControlMethods {
    // Provided methods
    fn create_str<W: WindowMethods, P: PointMethods, S: SizeMethods>(
        &self,
        parent: Option<&W>,
        id: c_int,
        value: &str,
        pos: &P,
        size: &S,
        style: c_long,
        min: c_double,
        max: c_double,
        initial: c_double,
        inc: c_double,
        name: &str,
    ) -> bool { ... }
    fn get_digits(&self) -> c_uint { ... }
    fn get_increment(&self) -> c_double { ... }
    fn get_max(&self) -> c_double { ... }
    fn get_min(&self) -> c_double { ... }
    fn get_text_value(&self) -> String { ... }
    fn get_value(&self) -> c_double { ... }
    fn set_digits(&self, digits: c_uint) { ... }
    fn set_increment(&self, inc: c_double) { ... }
    fn set_range(&self, min_val: c_double, max_val: c_double) { ... }
    fn set_value_str(&self, text: &str) { ... }
    fn set_value_double(&self, value: c_double) { ... }
}
This trait represents C++ wxSpinCtrlDouble class’s methods and inheritance.

See SpinCtrlDoubleIsOwned documentation for the class usage.

Provided Methods

fn create_str<W: WindowMethods, P: PointMethods, S: SizeMethods>( &self, parent: Option<&W>, id: c_int, value: &str, pos: &P, size: &S, style: c_long, min: c_double, max: c_double, initial: c_double, inc: c_double, name: &str, ) -> bool

Creation function called by the spin control constructor.

See C++ wxSpinCtrlDouble::Create()’s documentation.

fn get_digits(&self) -> c_uint

Gets precision of the value of the spin control.

See C++ wxSpinCtrlDouble::GetDigits()’s documentation.

fn get_increment(&self) -> c_double

fn get_max(&self) -> c_double

Gets maximal allowable value.

See C++ wxSpinCtrlDouble::GetMax()’s documentation.

fn get_min(&self) -> c_double

Gets minimal allowable value.

See C++ wxSpinCtrlDouble::GetMin()’s documentation.

fn get_text_value(&self) -> String

Returns the text in the text entry part of the control.

See C++ wxSpinCtrlDouble::GetTextValue()’s documentation.

fn get_value(&self) -> c_double

Gets the value of the spin control.

See C++ wxSpinCtrlDouble::GetValue()’s documentation.

fn set_digits(&self, digits: c_uint)

Sets precision of the value of the spin control.

See C++ wxSpinCtrlDouble::SetDigits()’s documentation.

fn set_increment(&self, inc: c_double)

fn set_range(&self, min_val: c_double, max_val: c_double)

Sets range of allowable values.

See C++ wxSpinCtrlDouble::SetRange()’s documentation.

fn set_value_str(&self, text: &str)

Sets the value of the spin control.

See C++ wxSpinCtrlDouble::SetValue()’s documentation.

fn set_value_double(&self, value: c_double)

Sets the value of the spin control.

See C++ wxSpinCtrlDouble::SetValue()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors