StdDialogButtonSizerMethods

Trait StdDialogButtonSizerMethods 

pub trait StdDialogButtonSizerMethods: BoxSizerMethods {
    // Provided methods
    fn add_button<B: ButtonMethods>(&self, button: Option<&B>) { ... }
    fn realize(&self) { ... }
    fn set_affirmative_button<B: ButtonMethods>(&self, button: Option<&B>) { ... }
    fn set_cancel_button<B: ButtonMethods>(&self, button: Option<&B>) { ... }
    fn set_negative_button<B: ButtonMethods>(&self, button: Option<&B>) { ... }
}
This trait represents C++ wxStdDialogButtonSizer class’s methods and inheritance.

See StdDialogButtonSizerIsOwned documentation for the class usage.

Provided Methods

fn add_button<B: ButtonMethods>(&self, button: Option<&B>)

Adds a button to the wxStdDialogButtonSizer.

See C++ wxStdDialogButtonSizer::AddButton()’s documentation.

fn realize(&self)

Rearranges the buttons and applies proper spacing between buttons to make them match the platform or toolkit’s interface guidelines.

See C++ wxStdDialogButtonSizer::Realize()’s documentation.

fn set_affirmative_button<B: ButtonMethods>(&self, button: Option<&B>)

Sets the affirmative button for the sizer.

See C++ wxStdDialogButtonSizer::SetAffirmativeButton()’s documentation.

fn set_cancel_button<B: ButtonMethods>(&self, button: Option<&B>)

Sets the cancel button for the sizer.

See C++ wxStdDialogButtonSizer::SetCancelButton()’s documentation.

fn set_negative_button<B: ButtonMethods>(&self, button: Option<&B>)

Sets the negative button for the sizer.

See C++ wxStdDialogButtonSizer::SetNegativeButton()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors