TaskBarIconMethods

Trait TaskBarIconMethods 

pub trait TaskBarIconMethods: EvtHandlerMethods {
    // Provided methods
    fn destroy(&self) { ... }
    fn is_icon_installed(&self) -> bool { ... }
    fn is_ok(&self) -> bool { ... }
    fn popup_menu<M: MenuMethods>(&self, menu: Option<&M>) -> bool { ... }
    fn remove_icon(&self) -> bool { ... }
    fn set_icon<B: BitmapBundleMethods>(&self, icon: &B, tooltip: &str) -> bool { ... }
    fn is_available() -> bool { ... }
}
This trait represents C++ wxTaskBarIcon class’s methods and inheritance.

See TaskBarIconIsOwned documentation for the class usage.

Provided Methods

fn destroy(&self)

This method is similar to wxWindow::Destroy and can be used to schedule the task bar icon object for the delayed destruction: it will be deleted during the next event loop iteration, which allows the task bar icon to process any pending events for it before being destroyed.

See C++ wxTaskBarIcon::Destroy()’s documentation.

fn is_icon_installed(&self) -> bool

Returns true if SetIcon() was called with no subsequent RemoveIcon().

See C++ wxTaskBarIcon::IsIconInstalled()’s documentation.

fn is_ok(&self) -> bool

Returns true if the object initialized successfully.

See C++ wxTaskBarIcon::IsOk()’s documentation.

fn popup_menu<M: MenuMethods>(&self, menu: Option<&M>) -> bool

Pops up a menu at the current mouse position.

See C++ wxTaskBarIcon::PopupMenu()’s documentation.

fn remove_icon(&self) -> bool

Removes the icon previously set with SetIcon().

See C++ wxTaskBarIcon::RemoveIcon()’s documentation.

fn set_icon<B: BitmapBundleMethods>(&self, icon: &B, tooltip: &str) -> bool

Sets the icon, and optional tooltip text.

See C++ wxTaskBarIcon::SetIcon()’s documentation.

fn is_available() -> bool

Returns true if system tray is available in the desktop environment the app runs under.

See C++ wxTaskBarIcon::IsAvailable()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<const OWNED: bool> TaskBarIconMethods for TaskBarIconIsOwned<OWNED>