TreeListCtrlMethods

Trait TreeListCtrlMethods 

pub trait TreeListCtrlMethods: WindowMethods {
Show 15 methods // Provided methods fn assign_image_list<I: ImageListMethods>(&self, image_list: Option<&I>) { ... } fn set_image_list<I: ImageListMethods>(&self, image_list: Option<&I>) { ... } fn append_column( &self, title: &str, width: c_int, align: c_int, flags: c_int, ) -> c_int { ... } fn clear_columns(&self) { ... } fn width_for(&self, text: &str) -> c_int { ... } fn delete_all_items(&self) { ... } fn get_root_item(&self) -> TreeListItem { ... } fn get_first_item(&self) -> TreeListItem { ... } fn get_selection(&self) -> TreeListItem { ... } fn select_all(&self) { ... } fn unselect_all(&self) { ... } fn get_sort_column( &self, col: *mut c_void, ascending_order: *mut c_void, ) -> bool { ... } fn set_item_comparator<T: TreeListItemComparatorMethods>( &self, comparator: Option<&T>, ) { ... } fn get_view(&self) -> WeakRef<Window> { ... } fn get_data_view(&self) -> WeakRef<DataViewCtrl> { ... }
}
This trait represents C++ wxTreeListCtrl class’s methods and inheritance.

See TreeListCtrlIsOwned documentation for the class usage.

Provided Methods

fn assign_image_list<I: ImageListMethods>(&self, image_list: Option<&I>)

Sets the image list and gives its ownership to the control.

See C++ wxTreeListCtrl::AssignImageList()’s documentation.

fn set_image_list<I: ImageListMethods>(&self, image_list: Option<&I>)

fn append_column( &self, title: &str, width: c_int, align: c_int, flags: c_int, ) -> c_int

Add a column with the given title and attributes.

See C++ wxTreeListCtrl::AppendColumn()’s documentation.

fn clear_columns(&self)

fn width_for(&self, text: &str) -> c_int

Get the width appropriate for showing the given text.

See C++ wxTreeListCtrl::WidthFor()’s documentation.

fn delete_all_items(&self)

fn get_root_item(&self) -> TreeListItem

Return the (never shown) root item.

See C++ wxTreeListCtrl::GetRootItem()’s documentation.

fn get_first_item(&self) -> TreeListItem

Return the first item in the tree.

See C++ wxTreeListCtrl::GetFirstItem()’s documentation.

fn get_selection(&self) -> TreeListItem

Return the currently selected item.

See C++ wxTreeListCtrl::GetSelection()’s documentation.

fn select_all(&self)

Select all the control items.

See C++ wxTreeListCtrl::SelectAll()’s documentation.

fn unselect_all(&self)

Deselect all the control items.

See C++ wxTreeListCtrl::UnselectAll()’s documentation.

fn get_sort_column( &self, col: *mut c_void, ascending_order: *mut c_void, ) -> bool

Return the column currently used for sorting, if any.

See C++ wxTreeListCtrl::GetSortColumn()’s documentation.

fn set_item_comparator<T: TreeListItemComparatorMethods>( &self, comparator: Option<&T>, )

Set the object to use for comparing the items.

See C++ wxTreeListCtrl::SetItemComparator()’s documentation.

fn get_view(&self) -> WeakRef<Window>

Return the view part of this control as a wxWindow.

See C++ wxTreeListCtrl::GetView()’s documentation.

fn get_data_view(&self) -> WeakRef<DataViewCtrl>

Return the view part of this control as wxDataViewCtrl.

See C++ wxTreeListCtrl::GetDataView()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors