UIActionSimulatorMethods

Trait UIActionSimulatorMethods 

pub trait UIActionSimulatorMethods: WxRustMethods {
    // Provided methods
    fn mouse_move_long(&self, x: c_long, y: c_long) -> bool { ... }
    fn mouse_move_point<P: PointMethods>(&self, point: &P) -> bool { ... }
    fn mouse_down(&self, button: c_int) -> bool { ... }
    fn mouse_up(&self, button: c_int) -> bool { ... }
    fn mouse_click(&self, button: c_int) -> bool { ... }
    fn mouse_dbl_click(&self, button: c_int) -> bool { ... }
    fn mouse_drag_drop(
        &self,
        x1: c_long,
        y1: c_long,
        x2: c_long,
        y2: c_long,
        button: c_int,
    ) -> bool { ... }
    fn key_down(&self, keycode: c_int, modifiers: c_int) -> bool { ... }
    fn key_up(&self, keycode: c_int, modifiers: c_int) -> bool { ... }
    fn char(&self, keycode: c_int, modifiers: c_int) -> bool { ... }
    fn select(&self, text: &str) -> bool { ... }
    fn text(&self, text: *const c_void) -> bool { ... }
}
This trait represents C++ wxUIActionSimulator class’s methods and inheritance.

See UIActionSimulatorIsOwned documentation for the class usage.

Provided Methods

fn mouse_move_long(&self, x: c_long, y: c_long) -> bool

Move the mouse to the specified coordinates.

See C++ wxUIActionSimulator::MouseMove()’s documentation.

fn mouse_move_point<P: PointMethods>(&self, point: &P) -> bool

Move the mouse to the specified coordinates.

See C++ wxUIActionSimulator::MouseMove()’s documentation.

fn mouse_down(&self, button: c_int) -> bool

fn mouse_up(&self, button: c_int) -> bool

fn mouse_click(&self, button: c_int) -> bool

fn mouse_dbl_click(&self, button: c_int) -> bool

fn mouse_drag_drop( &self, x1: c_long, y1: c_long, x2: c_long, y2: c_long, button: c_int, ) -> bool

Perform a drag and drop operation.

See C++ wxUIActionSimulator::MouseDragDrop()’s documentation.

fn key_down(&self, keycode: c_int, modifiers: c_int) -> bool

fn key_up(&self, keycode: c_int, modifiers: c_int) -> bool

fn char(&self, keycode: c_int, modifiers: c_int) -> bool

fn select(&self, text: &str) -> bool

Simulate selection of an item with the given text.

See C++ wxUIActionSimulator::Select()’s documentation.

fn text(&self, text: *const c_void) -> bool

Emulate typing in the keys representing the given string.

See C++ wxUIActionSimulator::Text()’s documentation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors