pub type DelegateRendererNative = DelegateRendererNativeIsOwned<true>;Expand description
wxDelegateRendererNative allows reuse of renderers code by forwarding all the wxRendererNative methods to the given object and thus allowing you to only modify some of its methods without having to reimplement all of them.
DelegateRendererNativerepresents a C++wxDelegateRendererNativeclass instance which your code has ownership,DelegateRendererNativeIsOwned<false>represents one which don’t own.- Use
DelegateRendererNative’snew()orBuildable::builder()(if available) to create an instance of this class. - See C++
wxDelegateRendererNativeclass’s documentation for more details.
Aliased Type
pub struct DelegateRendererNative(/* private fields */);