pub trait BookCtrlEventMethods: NotifyEventMethods {
// Provided methods
fn get_old_selection(&self) -> c_int { ... }
fn set_old_selection(&self, page: c_int) { ... }
fn set_selection(&self, page: c_int) { ... }
}Expand description
This trait represents C++ wxBookCtrlEvent class’s methods and inheritance.
See BookCtrlEventIsOwned documentation for the class usage.
Provided Methods
Sourcefn get_old_selection(&self) -> c_int
fn get_old_selection(&self) -> c_int
Returns the page that was selected before the change, wxNOT_FOUND if none was selected.
Sourcefn set_old_selection(&self, page: c_int)
fn set_old_selection(&self, page: c_int)
Sets the id of the page selected before the change.
Sourcefn set_selection(&self, page: c_int)
fn set_selection(&self, page: c_int)
Sets the selection member variable.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.