pub trait CalculateLayoutEventMethods: EventMethods {
// Provided methods
fn get_flags(&self) -> c_int { ... }
fn get_rect(&self) -> Rect { ... }
fn set_flags(&self, flags: c_int) { ... }
fn set_rect<R: RectMethods>(&self, rect: &R) { ... }
}Expand description
This trait represents C++ wxCalculateLayoutEvent class’s methods and inheritance.
See CalculateLayoutEventIsOwned documentation for the class usage.
Provided Methods
Sourcefn get_rect(&self) -> Rect
fn get_rect(&self) -> Rect
Before the event handler is entered, returns the remaining parent client area that the window could occupy.
Sourcefn set_rect<R: RectMethods>(&self, rect: &R)
fn set_rect<R: RectMethods>(&self, rect: &R)
Call this to specify the new remaining parent client area, after the space occupied by the window has been subtracted.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.