pub trait DirDialogMethods: DialogMethods {
// Provided methods
fn get_message(&self) -> String { ... }
fn get_path(&self) -> String { ... }
fn get_paths<A: ArrayStringMethods>(&self, paths: &A) { ... }
fn set_message(&self, message: &str) { ... }
fn set_path(&self, path: &str) { ... }
}Expand description
This trait represents C++ wxDirDialog class’s methods and inheritance.
See DirDialogIsOwned documentation for the class usage.
Provided Methods
Sourcefn get_message(&self) -> String
fn get_message(&self) -> String
Returns the message that will be displayed on the dialog.
Sourcefn get_paths<A: ArrayStringMethods>(&self, paths: &A)
fn get_paths<A: ArrayStringMethods>(&self, paths: &A)
Fills the array paths with the full paths of the chosen directories.
Sourcefn set_message(&self, message: &str)
fn set_message(&self, message: &str)
Sets the message that will be displayed on the dialog.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.