pub trait PreferencesEditorMethods: WxRustMethods {
// Provided methods
fn add_page<P: PreferencesPageMethods>(&self, page: Option<&P>) { ... }
fn show<W: WindowMethods>(&self, parent: Option<&W>) { ... }
fn dismiss(&self) { ... }
fn should_apply_changes_immediately() -> bool { ... }
fn shown_modally() -> bool { ... }
}Expand description
This trait represents C++ wxPreferencesEditor class’s methods and inheritance.
See PreferencesEditorIsOwned documentation for the class usage.
Provided Methods
Sourcefn add_page<P: PreferencesPageMethods>(&self, page: Option<&P>)
fn add_page<P: PreferencesPageMethods>(&self, page: Option<&P>)
Add a new page to the editor.
Sourcefn show<W: WindowMethods>(&self, parent: Option<&W>)
fn show<W: WindowMethods>(&self, parent: Option<&W>)
Show the preferences dialog or bring it to the top if it’s already shown.
Sourcefn should_apply_changes_immediately() -> bool
fn should_apply_changes_immediately() -> bool
Returns whether changes to values in preferences pages should be applied immediately or only when the user clicks the OK button.
See C++ wxPreferencesEditor::ShouldApplyChangesImmediately()’s documentation.
Sourcefn shown_modally() -> bool
fn shown_modally() -> bool
Returns whether the preferences dialog is shown modally.
See C++ wxPreferencesEditor::ShownModally()’s documentation.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.