pub trait QueryLayoutInfoEventMethods: EventMethods {
// Provided methods
fn get_flags(&self) -> c_int { ... }
fn get_requested_length(&self) -> c_int { ... }
fn get_size(&self) -> Size { ... }
fn set_flags(&self, flags: c_int) { ... }
fn set_requested_length(&self, length: c_int) { ... }
fn set_size<S: SizeMethods>(&self, size: &S) { ... }
}Expand description
This trait represents C++ wxQueryLayoutInfoEvent class’s methods and inheritance.
See QueryLayoutInfoEventIsOwned documentation for the class usage.
Provided Methods
Sourcefn get_requested_length(&self) -> c_int
fn get_requested_length(&self) -> c_int
Returns the requested length of the window in the direction of the window orientation.
See C++ wxQueryLayoutInfoEvent::GetRequestedLength()’s documentation.
Sourcefn get_size(&self) -> Size
fn get_size(&self) -> Size
Returns the size that the event handler specified to the event object as being the requested size of the window.
Sourcefn set_requested_length(&self, length: c_int)
fn set_requested_length(&self, length: c_int)
Sets the requested length of the window in the direction of the window orientation.
See C++ wxQueryLayoutInfoEvent::SetRequestedLength()’s documentation.
Sourcefn set_size<S: SizeMethods>(&self, size: &S)
fn set_size<S: SizeMethods>(&self, size: &S)
Call this to let the calling code know what the size of the window is.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.