pub trait SpinCtrlDoubleMethods: ControlMethods {
// Provided methods
fn create_str<W: WindowMethods, P: PointMethods, S: SizeMethods>(
&self,
parent: Option<&W>,
id: c_int,
value: &str,
pos: &P,
size: &S,
style: c_long,
min: c_double,
max: c_double,
initial: c_double,
inc: c_double,
name: &str,
) -> bool { ... }
fn get_digits(&self) -> c_uint { ... }
fn get_increment(&self) -> c_double { ... }
fn get_max(&self) -> c_double { ... }
fn get_min(&self) -> c_double { ... }
fn get_text_value(&self) -> String { ... }
fn get_value(&self) -> c_double { ... }
fn set_digits(&self, digits: c_uint) { ... }
fn set_increment(&self, inc: c_double) { ... }
fn set_range(&self, min_val: c_double, max_val: c_double) { ... }
fn set_value_str(&self, text: &str) { ... }
fn set_value_double(&self, value: c_double) { ... }
}Expand description
This trait represents C++ wxSpinCtrlDouble class’s methods and inheritance.
See SpinCtrlDoubleIsOwned documentation for the class usage.
Provided Methods
Sourcefn create_str<W: WindowMethods, P: PointMethods, S: SizeMethods>(
&self,
parent: Option<&W>,
id: c_int,
value: &str,
pos: &P,
size: &S,
style: c_long,
min: c_double,
max: c_double,
initial: c_double,
inc: c_double,
name: &str,
) -> bool
fn create_str<W: WindowMethods, P: PointMethods, S: SizeMethods>( &self, parent: Option<&W>, id: c_int, value: &str, pos: &P, size: &S, style: c_long, min: c_double, max: c_double, initial: c_double, inc: c_double, name: &str, ) -> bool
Creation function called by the spin control constructor.
Sourcefn get_digits(&self) -> c_uint
fn get_digits(&self) -> c_uint
Gets precision of the value of the spin control.
Sourcefn get_increment(&self) -> c_double
fn get_increment(&self) -> c_double
Gets the increment value.
Sourcefn get_text_value(&self) -> String
fn get_text_value(&self) -> String
Returns the text in the text entry part of the control.
Sourcefn set_digits(&self, digits: c_uint)
fn set_digits(&self, digits: c_uint)
Sets precision of the value of the spin control.
Sourcefn set_increment(&self, inc: c_double)
fn set_increment(&self, inc: c_double)
Sets the increment value.
Sourcefn set_value_str(&self, text: &str)
fn set_value_str(&self, text: &str)
Sets the value of the spin control.
Sourcefn set_value_double(&self, value: c_double)
fn set_value_double(&self, value: c_double)
Sets the value of the spin control.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.