pub trait TaskBarIconMethods: EvtHandlerMethods {
// Provided methods
fn destroy(&self) { ... }
fn is_icon_installed(&self) -> bool { ... }
fn is_ok(&self) -> bool { ... }
fn popup_menu<M: MenuMethods>(&self, menu: Option<&M>) -> bool { ... }
fn remove_icon(&self) -> bool { ... }
fn set_icon<B: BitmapBundleMethods>(&self, icon: &B, tooltip: &str) -> bool { ... }
fn is_available() -> bool { ... }
}Expand description
This trait represents C++ wxTaskBarIcon class’s methods and inheritance.
See TaskBarIconIsOwned documentation for the class usage.
Provided Methods
Sourcefn destroy(&self)
fn destroy(&self)
This method is similar to wxWindow::Destroy and can be used to schedule the task bar icon object for the delayed destruction: it will be deleted during the next event loop iteration, which allows the task bar icon to process any pending events for it before being destroyed.
Sourcefn is_icon_installed(&self) -> bool
fn is_icon_installed(&self) -> bool
Returns true if SetIcon() was called with no subsequent RemoveIcon().
Pops up a menu at the current mouse position.
Sourcefn remove_icon(&self) -> bool
fn remove_icon(&self) -> bool
Removes the icon previously set with SetIcon().
Sourcefn set_icon<B: BitmapBundleMethods>(&self, icon: &B, tooltip: &str) -> bool
fn set_icon<B: BitmapBundleMethods>(&self, icon: &B, tooltip: &str) -> bool
Sets the icon, and optional tooltip text.
Sourcefn is_available() -> bool
fn is_available() -> bool
Returns true if system tray is available in the desktop environment the app runs under.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.