pub trait TreeListCtrlMethods: WindowMethods {
Show 15 methods
// Provided methods
fn assign_image_list<I: ImageListMethods>(&self, image_list: Option<&I>) { ... }
fn set_image_list<I: ImageListMethods>(&self, image_list: Option<&I>) { ... }
fn append_column(
&self,
title: &str,
width: c_int,
align: c_int,
flags: c_int,
) -> c_int { ... }
fn clear_columns(&self) { ... }
fn width_for(&self, text: &str) -> c_int { ... }
fn delete_all_items(&self) { ... }
fn get_root_item(&self) -> TreeListItem { ... }
fn get_first_item(&self) -> TreeListItem { ... }
fn get_selection(&self) -> TreeListItem { ... }
fn select_all(&self) { ... }
fn unselect_all(&self) { ... }
fn get_sort_column(
&self,
col: *mut c_void,
ascending_order: *mut c_void,
) -> bool { ... }
fn set_item_comparator<T: TreeListItemComparatorMethods>(
&self,
comparator: Option<&T>,
) { ... }
fn get_view(&self) -> WeakRef<Window> { ... }
fn get_data_view(&self) -> WeakRef<DataViewCtrl> { ... }
}Expand description
This trait represents C++ wxTreeListCtrl class’s methods and inheritance.
See TreeListCtrlIsOwned documentation for the class usage.
Provided Methods
Sourcefn assign_image_list<I: ImageListMethods>(&self, image_list: Option<&I>)
fn assign_image_list<I: ImageListMethods>(&self, image_list: Option<&I>)
Sets the image list and gives its ownership to the control.
Sourcefn set_image_list<I: ImageListMethods>(&self, image_list: Option<&I>)
fn set_image_list<I: ImageListMethods>(&self, image_list: Option<&I>)
Sets the image list.
Sourcefn append_column(
&self,
title: &str,
width: c_int,
align: c_int,
flags: c_int,
) -> c_int
fn append_column( &self, title: &str, width: c_int, align: c_int, flags: c_int, ) -> c_int
Add a column with the given title and attributes.
Sourcefn clear_columns(&self)
fn clear_columns(&self)
Delete all columns.
Sourcefn delete_all_items(&self)
fn delete_all_items(&self)
Delete all tree items.
Sourcefn get_root_item(&self) -> TreeListItem
fn get_root_item(&self) -> TreeListItem
Return the (never shown) root item.
Sourcefn get_first_item(&self) -> TreeListItem
fn get_first_item(&self) -> TreeListItem
Return the first item in the tree.
Sourcefn get_selection(&self) -> TreeListItem
fn get_selection(&self) -> TreeListItem
Return the currently selected item.
Sourcefn select_all(&self)
fn select_all(&self)
Select all the control items.
Sourcefn unselect_all(&self)
fn unselect_all(&self)
Deselect all the control items.
Sourcefn get_sort_column(
&self,
col: *mut c_void,
ascending_order: *mut c_void,
) -> bool
fn get_sort_column( &self, col: *mut c_void, ascending_order: *mut c_void, ) -> bool
Return the column currently used for sorting, if any.
Sourcefn set_item_comparator<T: TreeListItemComparatorMethods>(
&self,
comparator: Option<&T>,
)
fn set_item_comparator<T: TreeListItemComparatorMethods>( &self, comparator: Option<&T>, )
Set the object to use for comparing the items.
See C++ wxTreeListCtrl::SetItemComparator()’s documentation.
Sourcefn get_data_view(&self) -> WeakRef<DataViewCtrl>
fn get_data_view(&self) -> WeakRef<DataViewCtrl>
Return the view part of this control as wxDataViewCtrl.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.